# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: offline_ticket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14offline_ticket.proto\"w\n\x0eOffline_Ticket\x12\x18\n\x10\x65ncrypted_ticket\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\x0c\n\x04kdf1\x18\x03 \x01(\x05\x12\r\n\x05salt1\x18\x04 \x01(\x0c\x12\x0c\n\x04kdf2\x18\x05 \x01(\x05\x12\r\n\x05salt2\x18\x06 \x01(\x0c')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'offline_ticket_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OFFLINE_TICKET._serialized_start=24
  _OFFLINE_TICKET._serialized_end=143
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_vac.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17steammessages_vac.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xec\x01\n(CFileVerification_SignatureCheck_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x11\n\tfile_size\x18\x03 \x01(\x04\x12\x16\n\x0e\x66ile_timestamp\x18\x04 \x01(\r\x12\x17\n\x0f\x66ile_timestamp2\x18\x05 \x01(\r\x12\x18\n\x10signature_result\x18\x06 \x01(\r\x12\x10\n\x08\x66ilename\x18\x07 \x01(\t\x12\x1e\n\x16\x63lient_package_version\x18\x08 \x01(\r\x12\x10\n\x08sha1hash\x18\t \x01(\x0c\"C\n)CFileVerification_SignatureCheck_Response\x12\x16\n\x0e\x64\x65ny_operation\x18\x01 \x01(\x08\"\xa5\x01\n+CFileVerification_SteamServiceCheck_Request\x12\x16\n\x0eservice_status\x18\x02 \x01(\r\x12\x1e\n\x16\x63lient_package_version\x18\x03 \x01(\r\x12\x15\n\rlauncher_type\x18\x04 \x01(\r\x12\x0f\n\x07os_type\x18\x05 \x01(\r\x12\x16\n\x0eservice_repair\x18\x06 \x01(\r\"F\n,CFileVerification_SteamServiceCheck_Response\x12\x16\n\x0e\x61ttempt_repair\x18\x01 \x01(\x08\x32\xed\x01\n\x10\x46ileVerification\x12g\n\x0eSignatureCheck\x12).CFileVerification_SignatureCheck_Request\x1a*.CFileVerification_SignatureCheck_Response\x12p\n\x11SteamServiceCheck\x12,.CFileVerification_SteamServiceCheck_Request\x1a-.CFileVerification_SteamServiceCheck_ResponseB\x03\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_vac_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\220\001\001'
  _CFILEVERIFICATION_SIGNATURECHECK_REQUEST._serialized_start=88
  _CFILEVERIFICATION_SIGNATURECHECK_REQUEST._serialized_end=324
  _CFILEVERIFICATION_SIGNATURECHECK_RESPONSE._serialized_start=326
  _CFILEVERIFICATION_SIGNATURECHECK_RESPONSE._serialized_end=393
  _CFILEVERIFICATION_STEAMSERVICECHECK_REQUEST._serialized_start=396
  _CFILEVERIFICATION_STEAMSERVICECHECK_REQUEST._serialized_end=561
  _CFILEVERIFICATION_STEAMSERVICECHECK_RESPONSE._serialized_start=563
  _CFILEVERIFICATION_STEAMSERVICECHECK_RESPONSE._serialized_end=633
  _FILEVERIFICATION._serialized_start=636
  _FILEVERIFICATION._serialized_end=873
_builder.BuildServices(DESCRIPTOR, 'steammessages_vac_pb2', globals())
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_virtualcontroller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%steammessages_virtualcontroller.proto\"\xc1\x01\n\x19\x43VirtualControllerElement\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32\x17.EControllerElementType:\x1ck_EControllerElementTypeNone\x12\x0f\n\x07visible\x18\x02 \x01(\x08\x12\x12\n\nx_position\x18\x03 \x01(\x02\x12\x12\n\ny_position\x18\x04 \x01(\x02\x12\x12\n\x07x_scale\x18\x05 \x01(\x02:\x01\x31\x12\x12\n\x07y_scale\x18\x06 \x01(\x02:\x01\x31\"Q\n\x17\x43VirtualControllerColor\x12\x0c\n\x01r\x18\x01 \x01(\x02:\x01\x31\x12\x0c\n\x01g\x18\x02 \x01(\x02:\x01\x31\x12\x0c\n\x01\x62\x18\x03 \x01(\x02:\x01\x31\x12\x0c\n\x01\x61\x18\x04 \x01(\x02:\x01\x31\"\x9f\x01\n\x18\x43VirtualControllerLayout\x12\x16\n\x0elayout_version\x18\x01 \x01(\x05\x12\x14\n\x0c\x61\x63tionset_id\x18\x02 \x01(\x05\x12,\n\x08\x65lements\x18\x04 \x03(\x0b\x32\x1a.CVirtualControllerElement\x12\'\n\x05\x63olor\x18\x05 \x01(\x0b\x32\x18.CVirtualControllerColor\"\xf2\x02\n\x19\x43VirtualControllerLayouts\x12*\n\x07layouts\x18\x01 \x03(\x0b\x32\x19.CVirtualControllerLayout\x12\x37\n\ninput_mode\x18\x02 \x01(\x0e\x32\x0b.EInputMode:\x16k_EInputModeController\x12\x34\n\nmouse_mode\x18\x03 \x01(\x0e\x32\x0b.EMouseMode:\x13k_EMouseModeUnknown\x12\x1f\n\x14trackpad_sensitivity\x18\x04 \x01(\x02:\x01\x31\x12!\n\x12pinch_zoom_enabled\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0cpinch_zoom_x\x18\x06 \x01(\x02:\x01\x30\x12\x17\n\x0cpinch_zoom_y\x18\x07 \x01(\x02:\x01\x30\x12\x1b\n\x10pinch_zoom_scale\x18\x08 \x01(\x02:\x01\x31\x12\x0e\n\x06shaken\x18\t \x01(\x08\x12\x17\n\x0fmouse_offscreen\x18\n \x01(\x08\"\x80\x05\n\x18\x43VirtualControllerConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\nactionsets\x18\x02 \x03(\x0b\x32#.CVirtualControllerConfig.ActionSet\x12\x43\n\x12\x64\x65\x66\x61ult_mouse_mode\x18\x03 \x01(\x0e\x32\x0b.EMouseMode:\x1ak_EMouseModeAbsoluteCursor\x1a\xe8\x02\n\x07\x43ontrol\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04icon\x18\x02 \x01(\t\x12\x14\n\x0cinput_source\x18\x03 \x01(\x05\x12\x12\n\ninput_mode\x18\x04 \x01(\x05\x12\x15\n\rinput_element\x18\x05 \x01(\x05\x12\x16\n\x0eoutput_gamepad\x18\x06 \x01(\x05\x12\x17\n\x0foutput_keyboard\x18\x07 \x01(\x05\x12\x14\n\x0coutput_mouse\x18\x08 \x01(\x05\x12\x17\n\x0ficon_foreground\x18\t \x01(\t\x12\x17\n\x0ficon_background\x18\n \x01(\t\x12\x14\n\x0cinput_toggle\x18\x0b \x01(\x08\x12(\n input_activate_stick_or_trackpad\x18\x0c \x01(\x05\x12\x17\n\x0f\x61\x63tivation_type\x18\r \x01(\x05\x12\x15\n\rlong_press_ms\x18\x0e \x01(\x05\x12\x17\n\x0f\x64ouble_press_ms\x18\x0f \x01(\x05\x1am\n\tActionSet\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x11\n\tparent_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x33\n\x08\x63ontrols\x18\x04 \x03(\x0b\x32!.CVirtualControllerConfig.Control\"\xcb\x01\n\x1f\x43VirtualControllerLayoutPackage\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x63reator\x18\x02 \x01(\x04\x12\x18\n\x10initial_revision\x18\x03 \x01(\r\x12\x16\n\x0esaved_revision\x18\x04 \x01(\r\x12)\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x19.CVirtualControllerConfig\x12+\n\x07layouts\x18\x06 \x01(\x0b\x32\x1a.CVirtualControllerLayouts\"\xb6\x01\n\x1e\x43VirtualControllerGlobalConfig\x12\x18\n\x10\x66\x65\x65\x64\x62\x61\x63k_enabled\x18\x01 \x01(\x08\x12\x1f\n\x11gyroscope_enabled\x18\x02 \x01(\x08:\x04true\x12\x1f\n\x11\x61uto_fade_enabled\x18\x03 \x01(\x08:\x04true\x12\x1c\n\x0erumble_enabled\x18\x04 \x01(\x08:\x04true\x12\x1a\n\x12shake_fade_enabled\x18\x05 \x01(\x08*|\n\nEInputMode\x12\x17\n\x13k_EInputModeUnknown\x10\x00\x12\x15\n\x11k_EInputModeMouse\x10\x01\x12\x1a\n\x16k_EInputModeController\x10\x02\x12\"\n\x1ek_EInputModeMouseAndController\x10\x03*\x96\x01\n\nEMouseMode\x12\x17\n\x13k_EMouseModeUnknown\x10\x00\x12\x1e\n\x1ak_EMouseModeRelativeCursor\x10\x01\x12\x1e\n\x1ak_EMouseModeAbsoluteCursor\x10\x02\x12\x15\n\x11k_EMouseModeTouch\x10\x03\x12\x18\n\x14k_EMouseModeRelative\x10\x04*\xa6\x0c\n\x16\x45\x43ontrollerElementType\x12)\n\x1ck_EControllerElementTypeNone\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12!\n\x1dk_EControllerElementTypeThumb\x10\x00\x12\'\n#k_EControllerElementTypeButtonSteam\x10\x01\x12(\n$k_EControllerElementTypeJoystickLeft\x10\x02\x12.\n*k_EControllerElementTypeButtonJoystickLeft\x10\x03\x12)\n%k_EControllerElementTypeJoystickRight\x10\x04\x12/\n+k_EControllerElementTypeButtonJoystickRight\x10\x05\x12 \n\x1ck_EControllerElementTypeDPad\x10\x06\x12#\n\x1fk_EControllerElementTypeButtonA\x10\x07\x12#\n\x1fk_EControllerElementTypeButtonB\x10\x08\x12#\n\x1fk_EControllerElementTypeButtonX\x10\t\x12#\n\x1fk_EControllerElementTypeButtonY\x10\n\x12(\n$k_EControllerElementTypeButtonSelect\x10\x0b\x12\'\n#k_EControllerElementTypeButtonStart\x10\x0c\x12-\n)k_EControllerElementTypeButtonTriggerLeft\x10\r\x12.\n*k_EControllerElementTypeButtonTriggerRight\x10\x0e\x12,\n(k_EControllerElementTypeButtonBumperLeft\x10\x0f\x12-\n)k_EControllerElementTypeButtonBumperRight\x10\x10\x12(\n$k_EControllerElementTypeButtonMacro0\x10\x11\x12(\n$k_EControllerElementTypeButtonMacro1\x10\x12\x12(\n$k_EControllerElementTypeButtonMacro2\x10\x13\x12(\n$k_EControllerElementTypeButtonMacro3\x10\x14\x12(\n$k_EControllerElementTypeButtonMacro4\x10\x15\x12(\n$k_EControllerElementTypeButtonMacro5\x10\x16\x12(\n$k_EControllerElementTypeButtonMacro6\x10\x17\x12(\n$k_EControllerElementTypeButtonMacro7\x10\x18\x12*\n&k_EControllerElementTypeTrackpadCenter\x10\x19\x12(\n$k_EControllerElementTypeTrackpadLeft\x10\x1a\x12)\n%k_EControllerElementTypeTrackpadRight\x10\x1b\x12$\n k_EControllerElementTypeKeyboard\x10\x1c\x12+\n\'k_EControllerElementTypeMagnifyingGlass\x10\x1d\x12.\n*k_EControllerElementTypeButtonMacro1Finger\x10\x1e\x12.\n*k_EControllerElementTypeButtonMacro2Finger\x10\x1f\x12\'\n#k_EControllerElementTypeRecordInput\x10 \x12)\n%k_EControllerElementTypePlaybackInput\x10!\x12!\n\x1dk_EControllerElementTypePaste\x10\"\x12\x1f\n\x1bk_EControllerElementTypeMax\x10#')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_virtualcontroller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EINPUTMODE._serialized_start=1889
  _EINPUTMODE._serialized_end=2013
  _EMOUSEMODE._serialized_start=2016
  _EMOUSEMODE._serialized_end=2166
  _ECONTROLLERELEMENTTYPE._serialized_start=2169
  _ECONTROLLERELEMENTTYPE._serialized_end=3743
  _CVIRTUALCONTROLLERELEMENT._serialized_start=42
  _CVIRTUALCONTROLLERELEMENT._serialized_end=235
  _CVIRTUALCONTROLLERCOLOR._serialized_start=237
  _CVIRTUALCONTROLLERCOLOR._serialized_end=318
  _CVIRTUALCONTROLLERLAYOUT._serialized_start=321
  _CVIRTUALCONTROLLERLAYOUT._serialized_end=480
  _CVIRTUALCONTROLLERLAYOUTS._serialized_start=483
  _CVIRTUALCONTROLLERLAYOUTS._serialized_end=853
  _CVIRTUALCONTROLLERCONFIG._serialized_start=856
  _CVIRTUALCONTROLLERCONFIG._serialized_end=1496
  _CVIRTUALCONTROLLERCONFIG_CONTROL._serialized_start=1025
  _CVIRTUALCONTROLLERCONFIG_CONTROL._serialized_end=1385
  _CVIRTUALCONTROLLERCONFIG_ACTIONSET._serialized_start=1387
  _CVIRTUALCONTROLLERCONFIG_ACTIONSET._serialized_end=1496
  _CVIRTUALCONTROLLERLAYOUTPACKAGE._serialized_start=1499
  _CVIRTUALCONTROLLERLAYOUTPACKAGE._serialized_end=1702
  _CVIRTUALCONTROLLERGLOBALCONFIG._serialized_start=1705
  _CVIRTUALCONTROLLERGLOBALCONFIG._serialized_end=1887
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientsettings.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"steammessages_clientsettings.proto\x1a google/protobuf/descriptor.proto\x1a\x0b\x65nums.proto\"|\n\nCMsgHotkey\x12\x10\n\x08key_code\x18\x01 \x01(\r\x12\x0f\n\x07\x61lt_key\x18\x02 \x01(\x08\x12\x11\n\tshift_key\x18\x03 \x01(\x08\x12\x10\n\x08\x63trl_key\x18\x04 \x01(\x08\x12\x10\n\x08meta_key\x18\x05 \x01(\x08\x12\x14\n\x0c\x64isplay_name\x18\x06 \x01(\t\"\xce\x01\n\x12\x43MsgSettingVariant\x12\x14\n\nvalue_bool\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bvalue_int32\x18\x02 \x01(\x05H\x00\x12\x16\n\x0cvalue_uint32\x18\x03 \x01(\rH\x00\x12\x16\n\x0cvalue_uint64\x18\x05 \x01(\x03H\x00\x12\x15\n\x0bvalue_float\x18\x06 \x01(\x02H\x00\x12\x16\n\x0cvalue_string\x18\x07 \x01(\tH\x00\x12#\n\x0cvalue_hotkey\x18\x08 \x01(\x0b\x32\x0b.CMsgHotkeyH\x00\x42\x07\n\x05value\"\xcd{\n\x12\x43MsgClientSettings\x12N\n\x15no_save_personal_info\x18\x01 \x01(\x08\x42/\x80\xa6\x1d\x01\x8a\xa6\x1d\'Software\\Valve\\Steam\\NoSavePersonalInfo\x12P\n\x16oobe_test_mode_enabled\x18\x02 \x01(\x08\x42\x30\x80\xa6\x1d\x01\x8a\xa6\x1d(Software\\Valve\\Steam\\OOBETestModeEnabled\x12 \n\x0ein_client_beta\x18\x03 \x01(\x08\x42\x08\x80\xa6\x1d\x05\x90\xa6\x1d\x01\x12%\n\x13is_steam_sideloaded\x18\x04 \x01(\x08\x42\x08\x80\xa6\x1d\x05\x90\xa6\x1d\x01\x12\x35\n\x11preferred_monitor\x18\x05 \x01(\tB\x1a\x80\xa6\x1d\x01\x8a\xa6\x1d\x12\x42igPicture/Monitor\x12p\n steam_cef_gpu_blocklist_disabled\x18\x06 \x01(\x08\x42\x46\x80\xa6\x1d\x04\x8a\xa6\x1d>HKEY_CURRENT_USER\\Software\\Valve\\Steam\\CEFGPUBlocklistDisabled\x12<\n\x13\x62igpicture_windowed\x18\x07 \x01(\x08\x42\x1f\x80\xa6\x1d\x01\x8a\xa6\x1d\x13\x42igPicture/Windowed\x90\xa6\x1d\x01\x12\x35\n\x0c\x64isplay_name\x18\x08 \x01(\tB\x1f\x80\xa6\x1d\x01\x8a\xa6\x1d\x17UI/Display/Current/Name\x12I\n\x13is_external_display\x18\t \x01(\x08\x42,\x80\xa6\x1d\x01\x8a\xa6\x1d$UI/Display/Current/IsExternalDisplay\x12\x45\n\x18steam_os_underscan_level\x18\n \x01(\x02\x42#\x80\xa6\x1d\x01\x8a\xa6\x1d\x1bSteamOSScreenUnderscanLevel\x12I\n\x1asteam_os_underscan_enabled\x18\x0b \x01(\x08\x42%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSteamOSScreenUnderscanEnabled\x12\x43\n\x10min_scale_factor\x18\x0c \x01(\x02\x42)\x80\xa6\x1d\x01\x8a\xa6\x1d!UI/Display/Current/MinScaleFactor\x12\x43\n\x10max_scale_factor\x18\r \x01(\x02\x42)\x80\xa6\x1d\x01\x8a\xa6\x1d!UI/Display/Current/MaxScaleFactor\x12\x45\n\x11\x61uto_scale_factor\x18\x0e \x01(\x02\x42*\x80\xa6\x1d\x01\x8a\xa6\x1d\"UI/Display/Current/AutoScaleFactor\x12:\n\nsmall_mode\x18\x10 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x1eSoftware\\Valve\\Steam\\SmallMode\x12I\n\x1bskip_steamvr_install_dialog\x18\x13 \x01(\x08\x42$\x80\xa6\x1d\x03\x8a\xa6\x1d\x1csystem\\SteamVRHMDVGUIWarning\x12O\n\x18\x61lways_show_user_chooser\x18\x14 \x01(\x08\x42-\x80\xa6\x1d\x01\x8a\xa6\x1d%WebStorage\\Auth\\AlwaysShowUserChooser\x12\x63\n\x16os_version_unsupported\x18\x15 \x01(\x08\x42\x43\x80\xa6\x1d\x04\x8a\xa6\x1d;HKEY_CURRENT_USER\\Software\\Valve\\Steam\\OSVersionUnsupported\x12\x30\n!show_family_sharing_notifications\x18\xb8\x17 \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12G\n\x1ashow_copy_count_in_library\x18\xb9\x17 \x01(\x08\x42\"\x80\xa6\x1d\x03\x8a\xa6\x1d\x16ShowCopyCountInLibrary\x98\xa6\x1d\x01\x12N\n\x1aoverlay_fps_counter_corner\x18\xa0\x1f \x01(\x05\x42)\x80\xa6\x1d\x03\x8a\xa6\x1d!system\\InGameOverlayShowFPSCorner\x12W\n!overlay_fps_counter_high_contrast\x18\xa1\x1f \x01(\x08\x42+\x80\xa6\x1d\x03\x8a\xa6\x1d#system\\InGameOverlayShowFPSContrast\x12[\n\x0boverlay_key\x18\xa2\x1f \x01(\x0b\x32\x0b.CMsgHotkeyB8\x80\xa6\x1d\x03\x8a\xa6\x1d\x1fsystem\\InGameOverlayShortcutKey\xba\xa6\x1d\rShift\tKEY_TAB\x12]\n\x0escreenshot_key\x18\xa3\x1f \x01(\x0b\x32\x0b.CMsgHotkeyB7\x80\xa6\x1d\x03\x8a\xa6\x1d$system\\InGameOverlayScreenshotHotKey\xba\xa6\x1d\x07KEY_F12\x12=\n\x0e\x65nable_overlay\x18\xa4\x1f \x01(\x08\x42$\x80\xa6\x1d\x03\x8a\xa6\x1d\x18system\\EnableGameOverlay\x98\xa6\x1d\x01\x12_\n\x1e\x65nable_screenshot_notification\x18\xa6\x1f \x01(\x08\x42\x36\x80\xa6\x1d\x03\x8a\xa6\x1d*system\\InGameOverlayScreenshotNotification\x98\xa6\x1d\x01\x12U\n\x17\x65nable_screenshot_sound\x18\xa7\x1f \x01(\x08\x42\x33\x80\xa6\x1d\x03\x8a\xa6\x1d\'system\\InGameOverlayScreenshotPlaySound\x98\xa6\x1d\x01\x12^\n\x1dsave_uncompressed_screenshots\x18\xa8\x1f \x01(\x08\x42\x36\x80\xa6\x1d\x03\x8a\xa6\x1d.system\\InGameOverlayScreenshotSaveUncompressed\x12\x1f\n\x10screenshots_path\x18\xa9\x1f \x01(\tB\x04\x80\xa6\x1d\x05\x12l\n\x11\x64\x65\x66\x61ult_ping_rate\x18\xaa\x1f \x01(\x05\x42P\x80\xa6\x1d\x05\xc0\xa6\x1d\x01\xca\xa6\x1d\x44\x43omputed default (automatic) server ping rate based on network speed\x12\x1f\n\x10server_ping_rate\x18\xab\x1f \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12(\n\x19steam_networking_share_ip\x18\xac\x1f \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12\x1f\n\x10web_browser_home\x18\xad\x1f \x01(\tB\x04\x80\xa6\x1d\x05\x12$\n\x15voice_mic_device_name\x18\xae\x1f \x01(\tB\x04\x80\xa6\x1d\x05\x12#\n\x14voice_mic_input_gain\x18\xaf\x1f \x01(\x02\x42\x04\x80\xa6\x1d\x05\x12(\n\x19voice_speaker_output_gain\x18\xb0\x1f \x01(\x02\x42\x04\x80\xa6\x1d\x05\x12)\n\x1avoice_push_to_talk_setting\x18\xb1\x1f \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12\x32\n\x16voice_push_to_talk_key\x18\xb2\x1f \x01(\x0b\x32\x0b.CMsgHotkeyB\x04\x80\xa6\x1d\x05\x12\x42\n\x19overlay_toolbar_list_view\x18\xb3\x1f \x01(\x08\x42\x1e\x80\xa6\x1d\x03\x8a\xa6\x1d\x16OverlayToolBarListView\x12T\n\x1c\x61lways_use_gamepadui_overlay\x18\xb4\x1f \x01(\x08\x42-\x80\xa6\x1d\x03\x8a\xa6\x1d%system\\EnableSCTenFootOverlayCheckNew\x12*\n\x0coverlay_tabs\x18\xb5\x1f \x01(\tB\x13\x80\xa6\x1d\x02\x8a\xa6\x1d\x0bOverlayTabs\x12j\n\x17overlay_scale_interface\x18\xb6\x1f \x01(\x08\x42H\x80\xa6\x1d\x04\x8a\xa6\x1d<HKEY_CURRENT_USER\\Software\\Valve\\Steam\\OverlayScaleInterface\x98\xa6\x1d\x01\x12Y\n\x1coverlay_restore_browser_tabs\x18\xb7\x1f \x01(\x08\x42\x32\x80\xa6\x1d\x03\x8a\xa6\x1d&system\\InGameOverlayRestoreBrowserTabs\x98\xa6\x1d\x01\x12R\n\x17\x65nable_avif_screenshots\x18\xb8\x1f \x01(\x08\x42\x30\x80\xa6\x1d\x03\x8a\xa6\x1d(system\\InGameOverlayScreenshotEnableAVIF\x12]\n overlay_fps_counter_detail_level\x18\xb9\x1f \x01(\x05\x42\x32\x80\xa6\x1d\x03\x8a\xa6\x1d&system\\InGameOverlayShowFPSDetailLevel\xa0\xa6\x1d\x01\x12\x64\n%overlay_fps_counter_saturation_factor\x18\xba\x1f \x01(\x02\x42\x34\x80\xa6\x1d\x03\x8a\xa6\x1d%system\\InGameOverlayShowFPSSaturation\xb5\xa6\x1d\x00\x00\x80?\x12[\n\x1doverlay_fps_counter_bgopacity\x18\xbb\x1f \x01(\x02\x42\x33\x80\xa6\x1d\x03\x8a\xa6\x1d$system\\InGameOverlayShowFPSBGOpacity\xb5\xa6\x1d\xcd\xccL?\x12\\\n overlay_fps_counter_scale_factor\x18\xbc\x1f \x01(\x02\x42\x31\x80\xa6\x1d\x03\x8a\xa6\x1d\"system\\InGameOverlayShowFPSScaling\xb5\xa6\x1d\x33\x33\x33?\x12\x63\n\x17overlay_fps_counter_key\x18\xbd\x1f \x01(\x0b\x32\x0b.CMsgHotkeyB4\x80\xa6\x1d\x03\x8a\xa6\x1d!system\\InGameOverlayShowFPSHotKey\xba\xa6\x1d\x07\x44\x65\x66\x61ult\x12W\n\x1doverlay_fps_counter_fps_graph\x18\xbe\x1f \x01(\x08\x42/\x80\xa6\x1d\x03\x8a\xa6\x1d#system\\InGameOverlayShowFPSGraphFPS\x98\xa6\x1d\x01\x12W\n\x1doverlay_fps_counter_cpu_graph\x18\xbf\x1f \x01(\x08\x42/\x80\xa6\x1d\x03\x8a\xa6\x1d#system\\InGameOverlayShowFPSGraphCPU\x98\xa6\x1d\x01\x12\x63\n#overlay_fps_counter_allow_km_driver\x18\xc0\x1f \x01(\x08\x42\x35\x80\xa6\x1d\x03\x8a\xa6\x1d)system\\InGameOverlayAllowKMDriveOnWindows\x98\xa6\x1d\x01\x12%\n\x16smooth_scroll_webviews\x18\x88\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12.\n\x1f\x65nable_gpu_accelerated_webviews\x18\x89\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12-\n\x1e\x65nable_hardware_video_decoding\x18\x8b\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12\x1d\n\x0erun_at_startup\x18\x8c\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12!\n\x12\x65nable_dpi_scaling\x18\x8d\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12I\n\x19\x65nable_marketing_messages\x18\x8e\' \x01(\x08\x42%\x80\xa6\x1d\x03\x8a\xa6\x1d\x19news\\NotifyAvailableGames\x98\xa6\x1d\x01\x12(\n\x19start_in_big_picture_mode\x18\x8f\' \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12>\n\x0ejumplist_flags\x18\x90\' \x01(\rB%\x80\xa6\x1d\x03\x8a\xa6\x1d\x17system\\JumplistSettings\xa8\xa6\x1d\xf0\xde\x04\x12<\n\x10\x65nable_ui_sounds\x18\x91\' \x01(\x08\x42!\x80\xa6\x1d\x03\x8a\xa6\x1d\x15system\\EnableUISounds\x98\xa6\x1d\x01\x12\x35\n\x12\x64isable_all_toasts\x18\xf0. \x01(\x08\x42\x18\x80\xa6\x1d\x02\x8a\xa6\x1d\x10\x44isableAllToasts\x12<\n\x16\x64isable_toasts_in_game\x18\xf1. \x01(\x08\x42\x1b\x80\xa6\x1d\x02\x8a\xa6\x1d\x13\x44isableToastsInGame\x12:\n\x13play_sound_on_toast\x18\xf2. \x01(\x08\x42\x1c\x80\xa6\x1d\x02\x8a\xa6\x1d\x10PlaySoundOnToast\x98\xa6\x1d\x01\x12\x39\n\x14library_display_size\x18\xd8\x36 \x01(\x05\x42\x1a\x80\xa6\x1d\x03\x8a\xa6\x1d\x12LibraryDisplaySize\x12\x63\n+library_whats_new_show_only_product_updates\x18\xd9\x36 \x01(\x08\x42-\x80\xa6\x1d\x02\x8a\xa6\x1d%LibraryWhatsNewShowOnlyProductUpdates\x12G\n\x1ashow_store_content_on_home\x18\xda\x36 \x01(\x08\x42\"\x80\xa6\x1d\x02\x8a\xa6\x1d\x16ShowStoreContentOnHome\x98\xa6\x1d\x01\x12\x19\n\nstart_page\x18\xdb\x36 \x01(\tB\x04\x80\xa6\x1d\x05\x12\x44\n\x1alibrary_low_bandwidth_mode\x18\xdc\x36 \x01(\x08\x42\x1f\x80\xa6\x1d\x03\x8a\xa6\x1d\x17LibraryLowBandwidthMode\x12:\n\x15library_low_perf_mode\x18\xdd\x36 \x01(\x08\x42\x1a\x80\xa6\x1d\x03\x8a\xa6\x1d\x12LibraryLowPerfMode\x12R\n!library_disable_community_content\x18\xde\x36 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x1eLibraryDisableCommunityContent\x12T\n!library_display_icon_in_game_list\x18\xdf\x36 \x01(\x08\x42(\x80\xa6\x1d\x03\x8a\xa6\x1d\x1cLibraryDisplayIconInGameList\x98\xa6\x1d\x01\x12O\n ready_to_play_includes_streaming\x18\xe0\x36 \x01(\x08\x42$\x80\xa6\x1d\x05\x8a\xa6\x1d\x1cReadyToPlayIncludesStreaming\x12\x41\n\x14show_steam_deck_info\x18\xe1\x36 \x01(\x08\x42\"\x80\xa6\x1d\x03\x8a\xa6\x1d\x1aShowSteamDeckInfoInLibrary\x12%\n\x16\x65nable_shader_precache\x18\xc0> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12\x32\n#enable_shader_background_processing\x18\xc1> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12(\n\x15shader_precached_size\x18\xc2> \x01(\x04\x42\x08\x80\xa6\x1d\x05\xc0\xa6\x1d\x01\x12-\n\x1aneeds_steam_service_repair\x18\xc3> \x01(\x08\x42\x08\x80\xa6\x1d\x05\xc0\xa6\x1d\x01\x12$\n\x15\x64ownload_peer_content\x18\xc4> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12\'\n\x18\x64ownload_rate_bits_per_s\x18\xc5> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12$\n\x15restrict_auto_updates\x18\xc6> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12*\n\x1brestrict_auto_updates_start\x18\xc7> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12(\n\x19restrict_auto_updates_end\x18\xc8> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12\x1e\n\x0f\x64ownload_region\x18\xc9> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12)\n\x1a\x64ownload_while_app_running\x18\xca> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12\x30\n!download_throttle_while_streaming\x18\xcb> \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12%\n\x16\x64ownload_throttle_rate\x18\xcc> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12*\n\x1b\x64\x65\x66\x61ult_app_update_behavior\x18\xcd> \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12\x1c\n\rcloud_enabled\x18\x90N \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12T\n\x17show_screenshot_manager\x18\x91N \x01(\x08\x42\x32\x80\xa6\x1d\x02\x8a\xa6\x1d*Software\\Valve\\Steam\\ShowScreenshotManager\x12\x1b\n\x0cmusic_volume\x18\xf8U \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12I\n\x18music_pause_on_app_start\x18\xf9U \x01(\x08\x42&\x80\xa6\x1d\x01\x8a\xa6\x1d\x1eMusic\\PauseOnAppStartedProcess\x12\x42\n\x19music_pause_on_voice_chat\x18\xfaU \x01(\x08\x42\x1e\x80\xa6\x1d\x01\x8a\xa6\x1d\x16Music\\PauseOnVoiceChat\x12W\n\x1bmusic_download_high_quality\x18\xfbU \x01(\x08\x42\x31\x80\xa6\x1d\x01\x8a\xa6\x1d)Music\\DownloadHighQualityAudioSoundtracks\x12R\n\x1bmusic_playlist_notification\x18\xfcU \x01(\x08\x42,\x80\xa6\x1d\x01\x8a\xa6\x1d$Music\\PlaylistNowPlayingNotification\x12x\n\x15\x62roadcast_permissions\x18\xe0] \x01(\x0e\x32\x15.EBroadcastPermission:\x1ek_EBroadcastPermissionDisabledB!\x80\xa6\x1d\x03\x8a\xa6\x1d\x15\x42roadcast\\Permissions\xa0\xa6\x1d\x01\x12>\n\x16\x62roadcast_output_width\x18\xe1] \x01(\x05\x42\x1d\x80\xa6\x1d\x03\x8a\xa6\x1d\x15\x42roadcast\\OutputWidth\x12\x45\n\x17\x62roadcast_output_height\x18\xe2] \x01(\x05\x42#\x80\xa6\x1d\x03\x8a\xa6\x1d\x16\x42roadcast\\OutputHeight\xa0\xa6\x1d\xd0\x05\x12:\n\x11\x62roadcast_bitrate\x18\xe3] \x01(\x05\x42\x1e\x80\xa6\x1d\x03\x8a\xa6\x1d\x11\x42roadcast\\MaxKbps\xa0\xa6\x1d\xc4\x13\x12\x7f\n\x19\x62roadcast_encoding_option\x18\xe4] \x01(\x0e\x32\x19.EBroadcastEncoderSetting:\x1ek_EBroadcastEncoderBestQualityB \x80\xa6\x1d\x03\x8a\xa6\x1d\x18\x42roadcast\\EncoderSetting\x12\x45\n\x1a\x62roadcast_record_all_video\x18\xe5] \x01(\x08\x42 \x80\xa6\x1d\x03\x8a\xa6\x1d\x18\x42roadcast\\IncludeDesktop\x12H\n\x1a\x62roadcast_record_all_audio\x18\xe6] \x01(\x08\x42#\x80\xa6\x1d\x03\x8a\xa6\x1d\x1b\x42roadcast\\RecordSystemAudio\x12\x41\n\x1b\x62roadcast_record_microphone\x18\xe7] \x01(\x08\x42\x1b\x80\xa6\x1d\x03\x8a\xa6\x1d\x13\x42roadcast\\RecordMic\x12\x45\n\x1b\x62roadcast_show_upload_stats\x18\xe8] \x01(\x08\x42\x1f\x80\xa6\x1d\x03\x8a\xa6\x1d\x17\x42roadcast\\ShowDebugInfo\x12I\n\x1c\x62roadcast_show_live_reminder\x18\xe9] \x01(\x08\x42\"\x80\xa6\x1d\x03\x8a\xa6\x1d\x16\x42roadcast\\ShowReminder\x98\xa6\x1d\x01\x12>\n\x15\x62roadcast_chat_corner\x18\xea] \x01(\x05\x42\x1e\x80\xa6\x1d\x03\x8a\xa6\x1d\x12\x42roadcast\\ShowChat\xa0\xa6\x1d\x01\x12U\n gamestream_hardware_video_encode\x18\xc8\x65 \x01(\x08\x42*\x80\xa6\x1d\x03\x8a\xa6\x1d\x1eGameStream\\HardwareVideoEncode\x98\xa6\x1d\x01\x12M\n\x1cgamestream_enable_video_h265\x18\xc9\x65 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x1aGameStream\\EnableVideoH265\x98\xa6\x1d\x01\x12\x63\n)steam_input_configurator_error_msg_enable\x18\xb1m \x01(\x08\x42/\x80\xa6\x1d\x01\x8a\xa6\x1d\'SteamInput/Configurator/ErrorMsgEnabled\x12U\n#controller_guide_button_focus_steam\x18\xb2m \x01(\x08\x42\'\x80\xa6\x1d\x03\x8a\xa6\x1d\x1b\x43ontroller_CheckGuideButton\x98\xa6\x1d\x01\x12\x45\n\x15\x63ontroller_ps_support\x18\xb3m \x01(\x05\x42%\x80\xa6\x1d\x03\x8a\xa6\x1d\x19SteamController_PSSupport\xa0\xa6\x1d\x01\x12\x45\n\x17\x63ontroller_xbox_support\x18\xb4m \x01(\x08\x42#\x80\xa6\x1d\x03\x8a\xa6\x1d\x1bSteamController_XBoxSupport\x12\x43\n\x16\x63ontroller_xbox_driver\x18\xb5m \x01(\x08\x42\"\x80\xa6\x1d\x03\x8a\xa6\x1d\x1aSteamController_XBoxDriver\x12I\n\x19\x63ontroller_switch_support\x18\xb6m \x01(\x08\x42%\x80\xa6\x1d\x03\x8a\xa6\x1d\x1dSteamController_SwitchSupport\x12R\n\x1a\x63ontroller_generic_support\x18\xb7m \x01(\x08\x42-\x80\xa6\x1d\x03\x8a\xa6\x1d%SteamController_GenericGamepadSupport\x12W\n\x1c\x63ontroller_power_off_timeout\x18\xb8m \x01(\x05\x42\x30\x80\xa6\x1d\x03\x8a\xa6\x1d$CSettingsPanelGameController.Timeout\xa0\xa6\x1d\x0f\x12R\n\x1bturn_off_controller_on_exit\x18\xb9m \x01(\x08\x42,\x80\xa6\x1d\x03\x8a\xa6\x1d$CSettingsPanelGameController.TurnOff\x12]\n#controller_combine_nintendo_joycons\x18\xbam \x01(\x08\x42/\x80\xa6\x1d\x01\x8a\xa6\x1d\'SteamInput/Configurator/CombinedJoycons\x12K\n\x17\x63ontroller_enable_chord\x18\xeb\xc5\x08 \x01(\x08\x42(\x80\xa6\x1d\x03\x8a\xa6\x1d\x1cSteamController_Enable_Chord\x98\xa6\x1d\x01\x12\x45\n\x14\x63ontroller_poll_rate\x18\xec\xc5\x08 \x01(\x08\x42%\x80\xa6\x1d\x03\x8a\xa6\x1d\x19SteamController_Poll_Rate\xa0\xa6\x1d\x02\x12I\n\x10startup_movie_id\x18\x80} \x01(\x04\x42.\x80\xa6\x1d\x01\x8a\xa6\x1d\"Customization/StartupMovie/MovieID\x90\xa6\x1d\x01\x12S\n\x18startup_movie_local_path\x18\x81} \x01(\tB0\x80\xa6\x1d\x01\x8a\xa6\x1d$Customization/StartupMovie/LocalPath\x90\xa6\x1d\x01\x12N\n\x15startup_movie_shuffle\x18\x82} \x01(\x08\x42.\x80\xa6\x1d\x01\x8a\xa6\x1d\"Customization/StartupMovie/Shuffle\x90\xa6\x1d\x01\x12X\n\x1dstartup_movie_used_for_resume\x18\x83} \x01(\x08\x42\x30\x80\xa6\x1d\x03\x8a\xa6\x1d(Customization/StartupMovie/UsedForResume\x12M\n\x1cgame_notes_enable_spellcheck\x18\xe9\x84\x01 \x01(\x08\x42%\x80\xa6\x1d\x02\x8a\xa6\x1d\x19GameNotesEnableSpellcheck\x98\xa6\x1d\x01\x12I\n\x18screenshot_items_per_row\x18\xd0\x8c\x01 \x01(\x05\x42%\x80\xa6\x1d\x02\x8a\xa6\x1d\x19ScreenshotViewItemsPerRow\xa0\xa6\x1d\x01\x12-\n\x1dgamerecording_background_path\x18\x99\x8e\x01 \x01(\tB\x04\x80\xa6\x1d\x05\x12^\n!gamerecording_background_max_keep\x18\x9a\x8e\x01 \x01(\tB1\x80\xa6\x1d\x03\x8a\xa6\x1d\x1fGameRecording\\BackgroundMaxKeep\xba\xa6\x1d\x06\x31\x32\x30min\x12i\n(gamerecording_background_time_resolution\x18\x9b\x8e\x01 \x01(\x05\x42\x35\x80\xa6\x1d\x03\x8a\xa6\x1d&GameRecording\\BackgroundTimeResolution\xb5\xa6\x1d\x00`jG\x12\x63\n\x1bgamerecording_background_mk\x18\x9f\x8e\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB/\x80\xa6\x1d\x03\x8a\xa6\x1d\x17GameRecording\\MarkerKey\xba\xa6\x1d\x0c\x43trl\tKEY_F12\x12\x63\n\x1bgamerecording_background_tg\x18\xa0\x8e\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB/\x80\xa6\x1d\x03\x8a\xa6\x1d\x17GameRecording\\ToggleKey\xba\xa6\x1d\x0c\x43trl\tKEY_F11\x12K\n\x1cgamerecording_background_a_m\x18\xa1\x8e\x01 \x01(\x08\x42#\x80\xa6\x1d\x03\x8a\xa6\x1d\x17GameRecording\\Audio_Mic\x98\xa6\x1d\x00\x12[\n\x1bgamerecording_video_bitrate\x18\xa2\x8e\x01 \x01(\tB4\x80\xa6\x1d\x03\x8a\xa6\x1d\x1aGameRecording\\VideoBitRate\xba\xa6\x1d\x0epreset_default\x12r\n\x1dgamerecording_background_mode\x18\xa4\x8e\x01 \x01(\x0e\x32\x08.EGRMode:\x0fk_EGRMode_NeverB.\x80\xa6\x1d\x03\x8a\xa6\x1d\"GameRecording\\BackgroundRecordMode\xa0\xa6\x1d\x00\x12v\n\x1egamerecording_background_audio\x18\xa5\x8e\x01 \x01(\x0e\x32\t.EGRAudio:\x0fk_EGRAudio_GameB0\x80\xa6\x1d\x03\x8a\xa6\x1d$GameRecording\\Recording_Audio_Option\xa0\xa6\x1d\x00\x12I\n\x15gamerecording_max_fps\x18\xa6\x8e\x01 \x01(\x05\x42(\x80\xa6\x1d\x03\x8a\xa6\x1d\x14GameRecording\\MaxFPS\xa0\xa6\x1d<\xd8\xa6\x1d\x18\xe0\xa6\x1dx\x12\\\n\x17gamerecording_hotkey_ic\x18\xa7\x8e\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB,\x80\xa6\x1d\x03\x8a\xa6\x1d\x1cGameRecording\\InstantClipKey\xba\xa6\x1d\x04None\x12T\n\x18gamerecording_ic_seconds\x18\xa8\x8e\x01 \x01(\x02\x42\x30\x80\xa6\x1d\x03\x8a\xa6\x1d!GameRecording\\InstantClipDuration\xb5\xa6\x1d\x00\x00\xf0\x41\x12\x82\x01\n\x1fgamerecording_export_limit_type\x18\xa9\x8e\x01 \x01(\x0e\x32\x13.EGRExportLimitType:\x1bk_EGRExportLimitType_NativeB%\x80\xa6\x1d\x03\x8a\xa6\x1d\x1dGameRecording\\ExportLimitType\x12W\n\"gamerecording_export_limit_size_mb\x18\xaa\x8e\x01 \x01(\x05\x42)\x80\xa6\x1d\x03\x8a\xa6\x1d\x1dGameRecording\\ExportLimitSize\xa0\xa6\x1d\x64\x12Z\n\"gamerecording_export_limit_bitrate\x18\xab\x8e\x01 \x01(\x05\x42,\x80\xa6\x1d\x03\x8a\xa6\x1d GameRecording\\ExportLimitBitrate\xa0\xa6\x1d\x01\x12W\n gamerecording_export_limit_width\x18\xac\x8e\x01 \x01(\x05\x42+\x80\xa6\x1d\x03\x8a\xa6\x1d\x1eGameRecording\\ExportLimitWidth\xa0\xa6\x1d\x80\x1e\x12Y\n!gamerecording_export_limit_height\x18\xad\x8e\x01 \x01(\x05\x42,\x80\xa6\x1d\x03\x8a\xa6\x1d\x1fGameRecording\\ExportLimitHeight\xa0\xa6\x1d\xf0\x10\x12_\n%gamerecording_export_limit_frame_rate\x18\xae\x8e\x01 \x01(\x05\x42.\x80\xa6\x1d\x03\x8a\xa6\x1d\"GameRecording\\ExportLimitFrameRate\xa0\xa6\x1d<\x12O\n\x1egamerecording_export_directory\x18\xaf\x8e\x01 \x01(\tB%\x80\xa6\x1d\x05\x8a\xa6\x1d\x1dGameRecording\\ExportDirectory\x12n\n\x1agamerecording_export_codec\x18\xb0\x8e\x01 \x01(\x0e\x32\r.EExportCodec:\x16k_EExportCodec_DefaultB!\x80\xa6\x1d\x03\x8a\xa6\x1d\x19GameRecording\\ExportCodec\x12Z\n\x1dgamerecording_video_maxheight\x18\xb1\x8e\x01 \x01(\x05\x42\x31\x80\xa6\x1d\x03\x8a\xa6\x1d\x1cGameRecording\\VideoMaxHeight\xa0\xa6\x1d\x00\xd8\xa6\x1d\x00\xe0\xa6\x1d\xf0\x10\x12N\n\x1cgamerecording_force_mic_mono\x18\xb2\x8e\x01 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x1aGameRecording\\ForceMicMono\x98\xa6\x1d\x00\x12^\n$gamerecording_automatic_gain_control\x18\xb3\x8e\x01 \x01(\x08\x42.\x80\xa6\x1d\x03\x8a\xa6\x1d\"GameRecording\\AutomaticGainControl\x98\xa6\x1d\x01\x12O\n\x1ashow_timestamps_in_console\x18\xa0\x9c\x01 \x01(\x08\x42)\x80\xa6\x1d\x03\x8a\xa6\x1d!Developer\\ShowTimestampsInConsole\x12N\n\nforce_oobe\x18\xa1\x9c\x01 \x01(\x08\x42\x38\x80\xa6\x1d\x04\x8a\xa6\x1d\x30HKEY_CURRENT_USER\\Software\\Valve\\Steam\\ForceOOBE\x12.\n\x1eoverride_browser_composer_mode\x18\xa2\x9c\x01 \x01(\x05\x42\x04\x80\xa6\x1d\x05\x12,\n\x1c\x63\x65\x66_remote_debugging_enabled\x18\xa3\x9c\x01 \x01(\x08\x42\x04\x80\xa6\x1d\x05\x12\x41\n\x13\x66orce_deck_perf_tab\x18\xa4\x9c\x01 \x01(\x08\x42\"\x80\xa6\x1d\x01\x8a\xa6\x1d\x1a\x44\x65veloper/ForceDeckPerfTab\x12L\n\x1b\x66orce_fake_mandatory_update\x18\xa5\x9c\x01 \x01(\x08\x42%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1d\x44\x65veloper/FakeMandatoryUpdate\x12@\n\x12hdr_compat_testing\x18\xa6\x9c\x01 \x01(\x08\x42\"\x80\xa6\x1d\x01\x8a\xa6\x1d\x1a\x44\x65veloper/HDRCompatTesting\x12\x42\n\x16\x64\x65veloper_mode_enabled\x18\xa7\x9c\x01 \x01(\x08\x42 \x80\xa6\x1d\x01\x8a\xa6\x1d\x18\x44\x65veloper/DevModeEnabled\x12U\n\x1dshow_advanced_update_channels\x18\xa8\x9c\x01 \x01(\x08\x42,\x80\xa6\x1d\x01\x8a\xa6\x1d$Developer/ShowAdvancedUpdateChannels\x12x\n\x1bgamescope_hdr_visualization\x18\x89\xa4\x01 \x01(\x0e\x32\x12.EHDRVisualization:\x18k_EHDRVisualization_NoneB#\x80\xa6\x1d\x03\x8a\xa6\x1d\x1bGamescope/HDRVisualization2\x12V\n\x1egamescope_app_target_framerate\x18\x8a\xa4\x01 \x01(\x05\x42,\x80\xa6\x1d\x03\x8a\xa6\x1d\x1cGamescope/AppTargetFrameRate\xa0\xa6\x1d\x00\xd0\xa6\x1d\x02\x12\x88\x01\n%gamescope_enable_app_target_framerate\x18\x8b\xa4\x01 \x01(\x08\x42W\x80\xa6\x1d\x04\x8a\xa6\x1dKHKEY_CURRENT_USER\\Software\\Valve\\Steam\\GamescopeEnableAppTargetRefreshRate2\x98\xa6\x1d\x01\x12S\n\x1cgamescope_disable_framelimit\x18\x8c\xa4\x01 \x01(\x08\x42+\x80\xa6\x1d\x03\x8a\xa6\x1d\x1bGamescope/DisableFrameLimit\x98\xa6\x1d\x00\xd0\xa6\x1d\x02\x12O\n\x1egamescope_display_refresh_rate\x18\x8d\xa4\x01 \x01(\x05\x42%\x80\xa6\x1d\x03\x8a\xa6\x1d\x15Gamescope/RefreshRate\xa0\xa6\x1d\x00\xd0\xa6\x1d\x02\x12\x63\n(gamescope_use_game_refresh_rate_in_steam\x18\x8e\xa4\x01 \x01(\x08\x42/\x80\xa6\x1d\x03\x8a\xa6\x1d#Developer/DynamicRefreshRateInSteam\x98\xa6\x1d\x01\x12Y\n!gamescope_disable_mura_correction\x18\x8f\xa4\x01 \x01(\x08\x42,\x80\xa6\x1d\x03\x8a\xa6\x1d Gamescope/MuraCorrectionDisabled\x98\xa6\x1d\x00\x12\x65\n(gamescope_include_steamui_in_screenshots\x18\x90\xa4\x01 \x01(\x08\x42\x31\x80\xa6\x1d\x03\x8a\xa6\x1d%Gamescope/IncludeSteamUIInScreenshots\x98\xa6\x1d\x00\x12I\n\x17gamescope_allow_tearing\x18\x91\xa4\x01 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x16Gamescope/AllowTearing\x98\xa6\x1d\x00\xd0\xa6\x1d\x01\x12I\n\x19gamescope_composite_debug\x18\x92\xa4\x01 \x01(\x08\x42$\x80\xa6\x1d\x03\x8a\xa6\x1d\x18Gamescope/CompositeDebug\x98\xa6\x1d\x00\x12I\n\x19gamescope_force_composite\x18\x93\xa4\x01 \x01(\x08\x42$\x80\xa6\x1d\x03\x8a\xa6\x1d\x18Gamescope/ForceComposite\x98\xa6\x1d\x00\x12]\n gamescope_game_resolution_global\x18\x94\xa4\x01 \x01(\tB1\x80\xa6\x1d\x03\x8a\xa6\x1d\x1eGamescope/GameResolutionGlobal\xba\xa6\x1d\x07\x44\x65\x66\x61ult\x12\x65\n\x16gamescope_guide_hotkey\x18\x95\xa4\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB6\x80\xa6\x1d\x03\x8a\xa6\x1d\x1dGamescope/GuideKeyboardHotkey\xba\xa6\x1d\rShift\tKEY_TAB\x12\x66\n\x14gamescope_qam_hotkey\x18\x96\xa4\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB9\x80\xa6\x1d\x03\x8a\xa6\x1d\x1bGamescope/QAMKeyboardHotkey\xba\xa6\x1d\x12\x43TRL\tShift\tKEY_TAB\x12\x45\n\x15gamescope_hdr_enabled\x18\x97\xa4\x01 \x01(\x08\x42$\x80\xa6\x1d\x01\x8a\xa6\x1d\x14Gamescope/HDREnabled\x98\xa6\x1d\x01\xd0\xa6\x1d\x03\x12g\n&gamescope_native_external_res_in_steam\x18\x98\xa4\x01 \x01(\x08\x42\x35\x80\xa6\x1d\x01\x8a\xa6\x1d-Gamescope/EnableSteamNativeExternalResolution\x12P\n\x1dsteamos_status_led_brightness\x18\xf0\xab\x01 \x01(\x05\x42\'\x80\xa6\x1d\x03\x8a\xa6\x1d\x1bSteamOS/StatusLEDBrightness\xa0\xa6\x1d\x64\x12L\n\x19steamos_tdp_limit_enabled\x18\xf1\xab\x01 \x01(\x08\x42\'\x80\xa6\x1d\x01\x8a\xa6\x1d\x17SteamOS/TDPLimitEnabled\x98\xa6\x1d\x00\xd0\xa6\x1d\x01\x12=\n\x11steamos_tdp_limit\x18\xf2\xab\x01 \x01(\x05\x42 \x80\xa6\x1d\x01\x8a\xa6\x1d\x10SteamOS/TDPLimit\xa0\xa6\x1d\x00\xd0\xa6\x1d\x01\x12=\n\x13steamos_cec_enabled\x18\xf3\xab\x01 \x01(\x08\x42\x1e\x80\xa6\x1d\x01\x8a\xa6\x1d\x12SteamOS/CECEnabled\x98\xa6\x1d\x01\x12\x46\n\x1asteamos_cec_wake_on_resume\x18\xf4\xab\x01 \x01(\x08\x42 \x80\xa6\x1d\x01\x8a\xa6\x1d\x14SteamOS/WakeOnResume\x98\xa6\x1d\x01\x12;\n\x12steamos_wifi_debug\x18\xf5\xab\x01 \x01(\x08\x42\x1d\x80\xa6\x1d\x01\x8a\xa6\x1d\x11SteamOS/WifiDebug\x98\xa6\x1d\x00\x12W\n!steamos_wifi_force_wpa_supplicant\x18\xf6\xab\x01 \x01(\x08\x42*\x80\xa6\x1d\x01\x8a\xa6\x1d\x1eSteamOS/WifiForceWPASupplicant\x98\xa6\x1d\x00\x12\x46\n\x17steamos_magnifier_scale\x18\xf7\xab\x01 \x01(\x05\x42#\x80\xa6\x1d\x03\x8a\xa6\x1d\x16SteamOS/MagnifierScale\xa0\xa6\x1d\x96\x01\x12Y\n steamos_manual_gpu_clock_enabled\x18\xf8\xab\x01 \x01(\x08\x42-\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSteamOS/ManualGPUClockEnabled\x98\xa6\x1d\x00\xd0\xa6\x1d\x01\x12P\n\x1bsteamos_manual_gpu_clock_hz\x18\xf9\xab\x01 \x01(\x05\x42)\x80\xa6\x1d\x01\x8a\xa6\x1d\x18SteamOS/ManualGPUClockHz\xa0\xa6\x1d\xe8\x07\xd0\xa6\x1d\x01\x12V\n$steamos_platform_performance_profile\x18\xfa\xab\x01 \x01(\tB&\x80\xa6\x1d\x01\x8a\xa6\x1d\x1aSteamOS/PerformanceProfile\xd0\xa6\x1d\x01\x12N\n\x1csteamos_charge_limit_enabled\x18\xfb\xab\x01 \x01(\x08\x42&\x80\xa6\x1d\x01\x8a\xa6\x1d\x1aSteamOS/ChargeLimitEnabled\x98\xa6\x1d\x00\x12?\n\x14steamos_charge_limit\x18\xfc\xab\x01 \x01(\x05\x42\x1f\x80\xa6\x1d\x01\x8a\xa6\x1d\x13SteamOS/ChargeLimit\xa0\xa6\x1dP\x12N\n\x1csteamos_charge_limit_devmode\x18\xfd\xab\x01 \x01(\x08\x42&\x80\xa6\x1d\x01\x8a\xa6\x1d\x1aSteamOS/ChargeLimitDevMode\x98\xa6\x1d\x00\x12\x46\n\x17setting_validation_bool\x18\xd9\xb3\x01 \x01(\x08\x42#\x80\xa6\x1d\x01\x8a\xa6\x1d\x1bSettingValidation/DummyBool\x12t\n\x17setting_validation_enum\x18\xda\xb3\x01 \x01(\x0e\x32\x12.EHDRVisualization:\x18k_EHDRVisualization_NoneB#\x80\xa6\x1d\x01\x8a\xa6\x1d\x1bSettingValidation/DummyEnum\x12H\n\x18setting_validation_int32\x18\xdb\xb3\x01 \x01(\x05\x42$\x80\xa6\x1d\x01\x8a\xa6\x1d\x1cSettingValidation/DummyInt32\x12J\n\x19setting_validation_uint32\x18\xdc\xb3\x01 \x01(\rB%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSettingValidation/DummyUInt32\x12J\n\x19setting_validation_uint64\x18\xdd\xb3\x01 \x01(\x04\x42%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSettingValidation/DummyUInt64\x12H\n\x18setting_validation_float\x18\xde\xb3\x01 \x01(\x02\x42$\x80\xa6\x1d\x01\x8a\xa6\x1d\x1cSettingValidation/DummyFloat\x12J\n\x19setting_validation_string\x18\xdf\xb3\x01 \x01(\tB%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSettingValidation/DummyString\x12W\n\x19setting_validation_hotkey\x18\xe0\xb3\x01 \x01(\x0b\x32\x0b.CMsgHotkeyB%\x80\xa6\x1d\x01\x8a\xa6\x1d\x1dSettingValidation/DummyHotkey\x12H\n\x18system_bluetooth_enabled\x18\xc0\xbb\x01 \x01(\x08\x42$\x80\xa6\x1d\x01\x8a\xa6\x1d\x18System/Bluetooth/Enabled\x98\xa6\x1d\x00\x12N\n\x18hardware_updater_enabled\x18\xc1\xbb\x01 \x01(\x08\x42*\x80\xa6\x1d\x01\x8a\xa6\x1d\x1eSystem/HardwareUpdater/Enabled\x98\xa6\x1d\x00\x12\x46\n\x19vr_show_perf_graph_in_hmd\x18\xa8\xc3\x01 \x01(\x08\x42!\x80\xa6\x1d\x03\x8a\xa6\x1d\x15VR/ShowPerfGraphInHMD\x98\xa6\x1d\x00\x12S\n\x1e\x61\x63\x63\x65ssibility_debug_visualizer\x18\x90\xcb\x01 \x01(\x08\x42)\x80\xa6\x1d\x03\x8a\xa6\x1d\x1d\x41\x63\x63\x65ssibility/DebugVisualizer\x98\xa6\x1d\x00\x12\\\n#accessibility_screen_reader_enabled\x18\x91\xcb\x01 \x01(\x08\x42-\x80\xa6\x1d\x01\x8a\xa6\x1d!Accessibility/ScreenReaderEnabled\x98\xa6\x1d\x00\x12Z\n accessibility_screen_reader_rate\x18\x92\xcb\x01 \x01(\x02\x42.\x80\xa6\x1d\x03\x8a\xa6\x1d\x1f\x41\x63\x63\x65ssibility/ScreenReaderPitch\xb5\xa6\x1d\x00\x00\x00?\x12Z\n!accessibility_screen_reader_pitch\x18\x93\xcb\x01 \x01(\x02\x42-\x80\xa6\x1d\x03\x8a\xa6\x1d\x1e\x41\x63\x63\x65ssibility/ScreenReaderRate\xb5\xa6\x1d\x00\x00\x00?\x12]\n\"accessibility_screen_reader_volume\x18\x94\xcb\x01 \x01(\x02\x42/\x80\xa6\x1d\x03\x8a\xa6\x1d Accessibility/ScreenReaderVolume\xb5\xa6\x1d\x00\x00\x80?\x12V\n accessibility_high_contrast_mode\x18\x95\xcb\x01 \x01(\x08\x42*\x80\xa6\x1d\x03\x8a\xa6\x1d\x1e\x41\x63\x63\x65ssibility/HighContrastMode\x98\xa6\x1d\x00\x12M\n\x1b\x61\x63\x63\x65ssibility_reduce_motion\x18\x96\xcb\x01 \x01(\x08\x42&\x80\xa6\x1d\x03\x8a\xa6\x1d\x1a\x41\x63\x63\x65ssibility/ReduceMotion\x98\xa6\x1d\x00\x12T\n\x1f\x61\x63\x63\x65ssibility_minimum_font_size\x18\x98\xcb\x01 \x01(\rB)\x80\xa6\x1d\x03\x8a\xa6\x1d\x1d\x41\x63\x63\x65ssibility/MinimumFontSize\xa0\xa6\x1d\x00\x12T\n\x1f\x61\x63\x63\x65ssibility_color_filter_name\x18\x99\xcb\x01 \x01(\tB)\x80\xa6\x1d\x01\x8a\xa6\x1d\x1d\x41\x63\x63\x65ssibility/ColorFilterName\xba\xa6\x1d\x00\x12U\n\x1e\x61\x63\x63\x65ssibility_desktop_ui_scale\x18\x9a\xcb\x01 \x01(\x02\x42+\x80\xa6\x1d\x01\x8a\xa6\x1d\x1c\x41\x63\x63\x65ssibility/DesktopUIScale\xb5\xa6\x1d\x00\x00\x80?*\x95\x02\n\x13\x45\x43lientSettingStore\x12!\n\x1dk_EClientSettingStore_Invalid\x10\x00\x12-\n)k_EClientSettingStore_ConfigStore_Install\x10\x01\x12\x31\n-k_EClientSettingStore_ConfigStore_UserRoaming\x10\x02\x12/\n+k_EClientSettingStore_ConfigStore_UserLocal\x10\x03\x12\"\n\x1ek_EClientSettingStore_Registry\x10\x04\x12$\n k_EClientSettingStore_CustomFunc\x10\x05*\xb5\x01\n\x19\x45OverlayToggleBarLocation\x12&\n\"k_EOverlayToggleBarLocation_Bottom\x10\x00\x12$\n k_EOverlayToggleBarLocation_Left\x10\x01\x12%\n!k_EOverlayToggleBarLocation_Right\x10\x02\x12#\n\x1fk_EOverlayToggleBarLocation_Top\x10\x03*\xab\x01\n\x13\x45SettingProfileMode\x12\x1e\n\x1ak_ESettingProfileMode_None\x10\x00\x12!\n\x1dk_ESettingProfileMode_PerGame\x10\x01\x12+\n\'k_ESettingProfileMode_PerGamePerDisplay\x10\x02\x12$\n k_ESettingProfileMode_PerDisplay\x10\x03*J\n\x07\x45GRMode\x12\x13\n\x0fk_EGRMode_Never\x10\x00\x12\x14\n\x10k_EGRMode_Always\x10\x01\x12\x14\n\x10k_EGRMode_Manual\x10\x02*M\n\x08\x45GRAudio\x12\x13\n\x0fk_EGRAudio_Game\x10\x00\x12\x15\n\x11k_EGRAudio_System\x10\x01\x12\x15\n\x11k_EGRAudio_Select\x10\x02*{\n\x12\x45GRExportLimitType\x12\x1f\n\x1bk_EGRExportLimitType_Native\x10\x00\x12!\n\x1dk_EGRExportLimitType_FileSize\x10\x01\x12!\n\x1dk_EGRExportLimitType_Advanced\x10\x02:k\n\rsetting_store\x12\x1d.google.protobuf.FieldOptions\x18\xe0\xd4\x03 \x01(\x0e\x32\x14.EClientSettingStore:\x1dk_EClientSettingStore_Invalid:5\n\x0csetting_name\x12\x1d.google.protobuf.FieldOptions\x18\xe1\xd4\x03 \x01(\t::\n\x11setting_pre_login\x12\x1d.google.protobuf.FieldOptions\x18\xe2\xd4\x03 \x01(\x08:=\n\x14setting_default_bool\x12\x1d.google.protobuf.FieldOptions\x18\xe3\xd4\x03 \x01(\x08:<\n\x13setting_default_int\x12\x1d.google.protobuf.FieldOptions\x18\xe4\xd4\x03 \x01(\x05:=\n\x14setting_default_uint\x12\x1d.google.protobuf.FieldOptions\x18\xe5\xd4\x03 \x01(\r:>\n\x15setting_default_float\x12\x1d.google.protobuf.FieldOptions\x18\xe6\xd4\x03 \x01(\x02:?\n\x16setting_default_string\x12\x1d.google.protobuf.FieldOptions\x18\xe7\xd4\x03 \x01(\t:9\n\x10setting_readonly\x12\x1d.google.protobuf.FieldOptions\x18\xe8\xd4\x03 \x01(\x08:<\n\x13setting_description\x12\x1d.google.protobuf.FieldOptions\x18\xe9\xd4\x03 \x01(\t:o\n\x14setting_profile_mode\x12\x1d.google.protobuf.FieldOptions\x18\xea\xd4\x03 \x01(\x0e\x32\x14.ESettingProfileMode:\x1ak_ESettingProfileMode_None::\n\x11setting_clamp_min\x12\x1d.google.protobuf.FieldOptions\x18\xeb\xd4\x03 \x01(\x03::\n\x11setting_clamp_max\x12\x1d.google.protobuf.FieldOptions\x18\xec\xd4\x03 \x01(\x03\x42\x05H\x01\x90\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'steammessages_clientsettings_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_store)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_name)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_pre_login)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_default_bool)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_default_int)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_default_uint)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_default_float)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_default_string)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_readonly)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_description)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_profile_mode)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_clamp_min)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(setting_clamp_max)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\220\001\001'
  _CMSGCLIENTSETTINGS.fields_by_name['no_save_personal_info']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['no_save_personal_info']._serialized_options = b'\200\246\035\001\212\246\035\'Software\\Valve\\Steam\\NoSavePersonalInfo'
  _CMSGCLIENTSETTINGS.fields_by_name['oobe_test_mode_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['oobe_test_mode_enabled']._serialized_options = b'\200\246\035\001\212\246\035(Software\\Valve\\Steam\\OOBETestModeEnabled'
  _CMSGCLIENTSETTINGS.fields_by_name['in_client_beta']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['in_client_beta']._serialized_options = b'\200\246\035\005\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['is_steam_sideloaded']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['is_steam_sideloaded']._serialized_options = b'\200\246\035\005\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['preferred_monitor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['preferred_monitor']._serialized_options = b'\200\246\035\001\212\246\035\022BigPicture/Monitor'
  _CMSGCLIENTSETTINGS.fields_by_name['steam_cef_gpu_blocklist_disabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steam_cef_gpu_blocklist_disabled']._serialized_options = b'\200\246\035\004\212\246\035>HKEY_CURRENT_USER\\Software\\Valve\\Steam\\CEFGPUBlocklistDisabled'
  _CMSGCLIENTSETTINGS.fields_by_name['bigpicture_windowed']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['bigpicture_windowed']._serialized_options = b'\200\246\035\001\212\246\035\023BigPicture/Windowed\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['display_name']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['display_name']._serialized_options = b'\200\246\035\001\212\246\035\027UI/Display/Current/Name'
  _CMSGCLIENTSETTINGS.fields_by_name['is_external_display']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['is_external_display']._serialized_options = b'\200\246\035\001\212\246\035$UI/Display/Current/IsExternalDisplay'
  _CMSGCLIENTSETTINGS.fields_by_name['steam_os_underscan_level']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steam_os_underscan_level']._serialized_options = b'\200\246\035\001\212\246\035\033SteamOSScreenUnderscanLevel'
  _CMSGCLIENTSETTINGS.fields_by_name['steam_os_underscan_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steam_os_underscan_enabled']._serialized_options = b'\200\246\035\001\212\246\035\035SteamOSScreenUnderscanEnabled'
  _CMSGCLIENTSETTINGS.fields_by_name['min_scale_factor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['min_scale_factor']._serialized_options = b'\200\246\035\001\212\246\035!UI/Display/Current/MinScaleFactor'
  _CMSGCLIENTSETTINGS.fields_by_name['max_scale_factor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['max_scale_factor']._serialized_options = b'\200\246\035\001\212\246\035!UI/Display/Current/MaxScaleFactor'
  _CMSGCLIENTSETTINGS.fields_by_name['auto_scale_factor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['auto_scale_factor']._serialized_options = b'\200\246\035\001\212\246\035\"UI/Display/Current/AutoScaleFactor'
  _CMSGCLIENTSETTINGS.fields_by_name['small_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['small_mode']._serialized_options = b'\200\246\035\003\212\246\035\036Software\\Valve\\Steam\\SmallMode'
  _CMSGCLIENTSETTINGS.fields_by_name['skip_steamvr_install_dialog']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['skip_steamvr_install_dialog']._serialized_options = b'\200\246\035\003\212\246\035\034system\\SteamVRHMDVGUIWarning'
  _CMSGCLIENTSETTINGS.fields_by_name['always_show_user_chooser']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['always_show_user_chooser']._serialized_options = b'\200\246\035\001\212\246\035%WebStorage\\Auth\\AlwaysShowUserChooser'
  _CMSGCLIENTSETTINGS.fields_by_name['os_version_unsupported']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['os_version_unsupported']._serialized_options = b'\200\246\035\004\212\246\035;HKEY_CURRENT_USER\\Software\\Valve\\Steam\\OSVersionUnsupported'
  _CMSGCLIENTSETTINGS.fields_by_name['show_family_sharing_notifications']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_family_sharing_notifications']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['show_copy_count_in_library']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_copy_count_in_library']._serialized_options = b'\200\246\035\003\212\246\035\026ShowCopyCountInLibrary\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_corner']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_corner']._serialized_options = b'\200\246\035\003\212\246\035!system\\InGameOverlayShowFPSCorner'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_high_contrast']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_high_contrast']._serialized_options = b'\200\246\035\003\212\246\035#system\\InGameOverlayShowFPSContrast'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_key']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_key']._serialized_options = b'\200\246\035\003\212\246\035\037system\\InGameOverlayShortcutKey\272\246\035\rShift\tKEY_TAB'
  _CMSGCLIENTSETTINGS.fields_by_name['screenshot_key']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['screenshot_key']._serialized_options = b'\200\246\035\003\212\246\035$system\\InGameOverlayScreenshotHotKey\272\246\035\007KEY_F12'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_overlay']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_overlay']._serialized_options = b'\200\246\035\003\212\246\035\030system\\EnableGameOverlay\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_screenshot_notification']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_screenshot_notification']._serialized_options = b'\200\246\035\003\212\246\035*system\\InGameOverlayScreenshotNotification\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_screenshot_sound']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_screenshot_sound']._serialized_options = b'\200\246\035\003\212\246\035\'system\\InGameOverlayScreenshotPlaySound\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['save_uncompressed_screenshots']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['save_uncompressed_screenshots']._serialized_options = b'\200\246\035\003\212\246\035.system\\InGameOverlayScreenshotSaveUncompressed'
  _CMSGCLIENTSETTINGS.fields_by_name['screenshots_path']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['screenshots_path']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['default_ping_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['default_ping_rate']._serialized_options = b'\200\246\035\005\300\246\035\001\312\246\035DComputed default (automatic) server ping rate based on network speed'
  _CMSGCLIENTSETTINGS.fields_by_name['server_ping_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['server_ping_rate']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['steam_networking_share_ip']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steam_networking_share_ip']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['web_browser_home']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['web_browser_home']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['voice_mic_device_name']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['voice_mic_device_name']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['voice_mic_input_gain']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['voice_mic_input_gain']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['voice_speaker_output_gain']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['voice_speaker_output_gain']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['voice_push_to_talk_setting']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['voice_push_to_talk_setting']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['voice_push_to_talk_key']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['voice_push_to_talk_key']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_toolbar_list_view']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_toolbar_list_view']._serialized_options = b'\200\246\035\003\212\246\035\026OverlayToolBarListView'
  _CMSGCLIENTSETTINGS.fields_by_name['always_use_gamepadui_overlay']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['always_use_gamepadui_overlay']._serialized_options = b'\200\246\035\003\212\246\035%system\\EnableSCTenFootOverlayCheckNew'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_tabs']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_tabs']._serialized_options = b'\200\246\035\002\212\246\035\013OverlayTabs'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_scale_interface']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_scale_interface']._serialized_options = b'\200\246\035\004\212\246\035<HKEY_CURRENT_USER\\Software\\Valve\\Steam\\OverlayScaleInterface\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_restore_browser_tabs']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_restore_browser_tabs']._serialized_options = b'\200\246\035\003\212\246\035&system\\InGameOverlayRestoreBrowserTabs\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_avif_screenshots']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_avif_screenshots']._serialized_options = b'\200\246\035\003\212\246\035(system\\InGameOverlayScreenshotEnableAVIF'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_detail_level']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_detail_level']._serialized_options = b'\200\246\035\003\212\246\035&system\\InGameOverlayShowFPSDetailLevel\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_saturation_factor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_saturation_factor']._serialized_options = b'\200\246\035\003\212\246\035%system\\InGameOverlayShowFPSSaturation\265\246\035\000\000\200?'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_bgopacity']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_bgopacity']._serialized_options = b'\200\246\035\003\212\246\035$system\\InGameOverlayShowFPSBGOpacity\265\246\035\315\314L?'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_scale_factor']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_scale_factor']._serialized_options = b'\200\246\035\003\212\246\035\"system\\InGameOverlayShowFPSScaling\265\246\035333?'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_key']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_key']._serialized_options = b'\200\246\035\003\212\246\035!system\\InGameOverlayShowFPSHotKey\272\246\035\007Default'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_fps_graph']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_fps_graph']._serialized_options = b'\200\246\035\003\212\246\035#system\\InGameOverlayShowFPSGraphFPS\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_cpu_graph']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_cpu_graph']._serialized_options = b'\200\246\035\003\212\246\035#system\\InGameOverlayShowFPSGraphCPU\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_allow_km_driver']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['overlay_fps_counter_allow_km_driver']._serialized_options = b'\200\246\035\003\212\246\035)system\\InGameOverlayAllowKMDriveOnWindows\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['smooth_scroll_webviews']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['smooth_scroll_webviews']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_gpu_accelerated_webviews']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_gpu_accelerated_webviews']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_hardware_video_decoding']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_hardware_video_decoding']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['run_at_startup']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['run_at_startup']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_dpi_scaling']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_dpi_scaling']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_marketing_messages']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_marketing_messages']._serialized_options = b'\200\246\035\003\212\246\035\031news\\NotifyAvailableGames\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['start_in_big_picture_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['start_in_big_picture_mode']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['jumplist_flags']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['jumplist_flags']._serialized_options = b'\200\246\035\003\212\246\035\027system\\JumplistSettings\250\246\035\360\336\004'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_ui_sounds']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_ui_sounds']._serialized_options = b'\200\246\035\003\212\246\035\025system\\EnableUISounds\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['disable_all_toasts']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['disable_all_toasts']._serialized_options = b'\200\246\035\002\212\246\035\020DisableAllToasts'
  _CMSGCLIENTSETTINGS.fields_by_name['disable_toasts_in_game']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['disable_toasts_in_game']._serialized_options = b'\200\246\035\002\212\246\035\023DisableToastsInGame'
  _CMSGCLIENTSETTINGS.fields_by_name['play_sound_on_toast']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['play_sound_on_toast']._serialized_options = b'\200\246\035\002\212\246\035\020PlaySoundOnToast\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['library_display_size']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_display_size']._serialized_options = b'\200\246\035\003\212\246\035\022LibraryDisplaySize'
  _CMSGCLIENTSETTINGS.fields_by_name['library_whats_new_show_only_product_updates']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_whats_new_show_only_product_updates']._serialized_options = b'\200\246\035\002\212\246\035%LibraryWhatsNewShowOnlyProductUpdates'
  _CMSGCLIENTSETTINGS.fields_by_name['show_store_content_on_home']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_store_content_on_home']._serialized_options = b'\200\246\035\002\212\246\035\026ShowStoreContentOnHome\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['start_page']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['start_page']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['library_low_bandwidth_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_low_bandwidth_mode']._serialized_options = b'\200\246\035\003\212\246\035\027LibraryLowBandwidthMode'
  _CMSGCLIENTSETTINGS.fields_by_name['library_low_perf_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_low_perf_mode']._serialized_options = b'\200\246\035\003\212\246\035\022LibraryLowPerfMode'
  _CMSGCLIENTSETTINGS.fields_by_name['library_disable_community_content']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_disable_community_content']._serialized_options = b'\200\246\035\003\212\246\035\036LibraryDisableCommunityContent'
  _CMSGCLIENTSETTINGS.fields_by_name['library_display_icon_in_game_list']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['library_display_icon_in_game_list']._serialized_options = b'\200\246\035\003\212\246\035\034LibraryDisplayIconInGameList\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['ready_to_play_includes_streaming']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['ready_to_play_includes_streaming']._serialized_options = b'\200\246\035\005\212\246\035\034ReadyToPlayIncludesStreaming'
  _CMSGCLIENTSETTINGS.fields_by_name['show_steam_deck_info']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_steam_deck_info']._serialized_options = b'\200\246\035\003\212\246\035\032ShowSteamDeckInfoInLibrary'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_shader_precache']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_shader_precache']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['enable_shader_background_processing']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['enable_shader_background_processing']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['shader_precached_size']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['shader_precached_size']._serialized_options = b'\200\246\035\005\300\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['needs_steam_service_repair']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['needs_steam_service_repair']._serialized_options = b'\200\246\035\005\300\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['download_peer_content']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_peer_content']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['download_rate_bits_per_s']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_rate_bits_per_s']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates_start']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates_start']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates_end']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['restrict_auto_updates_end']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['download_region']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_region']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['download_while_app_running']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_while_app_running']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['download_throttle_while_streaming']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_throttle_while_streaming']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['download_throttle_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['download_throttle_rate']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['default_app_update_behavior']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['default_app_update_behavior']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['cloud_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['cloud_enabled']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['show_screenshot_manager']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_screenshot_manager']._serialized_options = b'\200\246\035\002\212\246\035*Software\\Valve\\Steam\\ShowScreenshotManager'
  _CMSGCLIENTSETTINGS.fields_by_name['music_volume']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['music_volume']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['music_pause_on_app_start']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['music_pause_on_app_start']._serialized_options = b'\200\246\035\001\212\246\035\036Music\\PauseOnAppStartedProcess'
  _CMSGCLIENTSETTINGS.fields_by_name['music_pause_on_voice_chat']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['music_pause_on_voice_chat']._serialized_options = b'\200\246\035\001\212\246\035\026Music\\PauseOnVoiceChat'
  _CMSGCLIENTSETTINGS.fields_by_name['music_download_high_quality']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['music_download_high_quality']._serialized_options = b'\200\246\035\001\212\246\035)Music\\DownloadHighQualityAudioSoundtracks'
  _CMSGCLIENTSETTINGS.fields_by_name['music_playlist_notification']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['music_playlist_notification']._serialized_options = b'\200\246\035\001\212\246\035$Music\\PlaylistNowPlayingNotification'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_permissions']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_permissions']._serialized_options = b'\200\246\035\003\212\246\035\025Broadcast\\Permissions\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_output_width']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_output_width']._serialized_options = b'\200\246\035\003\212\246\035\025Broadcast\\OutputWidth'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_output_height']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_output_height']._serialized_options = b'\200\246\035\003\212\246\035\026Broadcast\\OutputHeight\240\246\035\320\005'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_bitrate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_bitrate']._serialized_options = b'\200\246\035\003\212\246\035\021Broadcast\\MaxKbps\240\246\035\304\023'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_encoding_option']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_encoding_option']._serialized_options = b'\200\246\035\003\212\246\035\030Broadcast\\EncoderSetting'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_all_video']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_all_video']._serialized_options = b'\200\246\035\003\212\246\035\030Broadcast\\IncludeDesktop'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_all_audio']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_all_audio']._serialized_options = b'\200\246\035\003\212\246\035\033Broadcast\\RecordSystemAudio'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_microphone']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_record_microphone']._serialized_options = b'\200\246\035\003\212\246\035\023Broadcast\\RecordMic'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_show_upload_stats']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_show_upload_stats']._serialized_options = b'\200\246\035\003\212\246\035\027Broadcast\\ShowDebugInfo'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_show_live_reminder']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_show_live_reminder']._serialized_options = b'\200\246\035\003\212\246\035\026Broadcast\\ShowReminder\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_chat_corner']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['broadcast_chat_corner']._serialized_options = b'\200\246\035\003\212\246\035\022Broadcast\\ShowChat\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamestream_hardware_video_encode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamestream_hardware_video_encode']._serialized_options = b'\200\246\035\003\212\246\035\036GameStream\\HardwareVideoEncode\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamestream_enable_video_h265']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamestream_enable_video_h265']._serialized_options = b'\200\246\035\003\212\246\035\032GameStream\\EnableVideoH265\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steam_input_configurator_error_msg_enable']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steam_input_configurator_error_msg_enable']._serialized_options = b'\200\246\035\001\212\246\035\'SteamInput/Configurator/ErrorMsgEnabled'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_guide_button_focus_steam']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_guide_button_focus_steam']._serialized_options = b'\200\246\035\003\212\246\035\033Controller_CheckGuideButton\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_ps_support']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_ps_support']._serialized_options = b'\200\246\035\003\212\246\035\031SteamController_PSSupport\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_xbox_support']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_xbox_support']._serialized_options = b'\200\246\035\003\212\246\035\033SteamController_XBoxSupport'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_xbox_driver']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_xbox_driver']._serialized_options = b'\200\246\035\003\212\246\035\032SteamController_XBoxDriver'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_switch_support']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_switch_support']._serialized_options = b'\200\246\035\003\212\246\035\035SteamController_SwitchSupport'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_generic_support']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_generic_support']._serialized_options = b'\200\246\035\003\212\246\035%SteamController_GenericGamepadSupport'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_power_off_timeout']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_power_off_timeout']._serialized_options = b'\200\246\035\003\212\246\035$CSettingsPanelGameController.Timeout\240\246\035\017'
  _CMSGCLIENTSETTINGS.fields_by_name['turn_off_controller_on_exit']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['turn_off_controller_on_exit']._serialized_options = b'\200\246\035\003\212\246\035$CSettingsPanelGameController.TurnOff'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_combine_nintendo_joycons']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_combine_nintendo_joycons']._serialized_options = b'\200\246\035\001\212\246\035\'SteamInput/Configurator/CombinedJoycons'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_enable_chord']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_enable_chord']._serialized_options = b'\200\246\035\003\212\246\035\034SteamController_Enable_Chord\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['controller_poll_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['controller_poll_rate']._serialized_options = b'\200\246\035\003\212\246\035\031SteamController_Poll_Rate\240\246\035\002'
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_id']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_id']._serialized_options = b'\200\246\035\001\212\246\035\"Customization/StartupMovie/MovieID\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_local_path']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_local_path']._serialized_options = b'\200\246\035\001\212\246\035$Customization/StartupMovie/LocalPath\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_shuffle']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_shuffle']._serialized_options = b'\200\246\035\001\212\246\035\"Customization/StartupMovie/Shuffle\220\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_used_for_resume']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['startup_movie_used_for_resume']._serialized_options = b'\200\246\035\003\212\246\035(Customization/StartupMovie/UsedForResume'
  _CMSGCLIENTSETTINGS.fields_by_name['game_notes_enable_spellcheck']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['game_notes_enable_spellcheck']._serialized_options = b'\200\246\035\002\212\246\035\031GameNotesEnableSpellcheck\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['screenshot_items_per_row']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['screenshot_items_per_row']._serialized_options = b'\200\246\035\002\212\246\035\031ScreenshotViewItemsPerRow\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_path']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_path']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_max_keep']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_max_keep']._serialized_options = b'\200\246\035\003\212\246\035\037GameRecording\\BackgroundMaxKeep\272\246\035\006120min'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_time_resolution']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_time_resolution']._serialized_options = b'\200\246\035\003\212\246\035&GameRecording\\BackgroundTimeResolution\265\246\035\000`jG'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_mk']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_mk']._serialized_options = b'\200\246\035\003\212\246\035\027GameRecording\\MarkerKey\272\246\035\014Ctrl\tKEY_F12'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_tg']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_tg']._serialized_options = b'\200\246\035\003\212\246\035\027GameRecording\\ToggleKey\272\246\035\014Ctrl\tKEY_F11'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_a_m']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_a_m']._serialized_options = b'\200\246\035\003\212\246\035\027GameRecording\\Audio_Mic\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_video_bitrate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_video_bitrate']._serialized_options = b'\200\246\035\003\212\246\035\032GameRecording\\VideoBitRate\272\246\035\016preset_default'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_mode']._serialized_options = b'\200\246\035\003\212\246\035\"GameRecording\\BackgroundRecordMode\240\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_audio']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_background_audio']._serialized_options = b'\200\246\035\003\212\246\035$GameRecording\\Recording_Audio_Option\240\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_max_fps']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_max_fps']._serialized_options = b'\200\246\035\003\212\246\035\024GameRecording\\MaxFPS\240\246\035<\330\246\035\030\340\246\035x'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_hotkey_ic']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_hotkey_ic']._serialized_options = b'\200\246\035\003\212\246\035\034GameRecording\\InstantClipKey\272\246\035\004None'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_ic_seconds']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_ic_seconds']._serialized_options = b'\200\246\035\003\212\246\035!GameRecording\\InstantClipDuration\265\246\035\000\000\360A'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_type']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_type']._serialized_options = b'\200\246\035\003\212\246\035\035GameRecording\\ExportLimitType'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_size_mb']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_size_mb']._serialized_options = b'\200\246\035\003\212\246\035\035GameRecording\\ExportLimitSize\240\246\035d'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_bitrate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_bitrate']._serialized_options = b'\200\246\035\003\212\246\035 GameRecording\\ExportLimitBitrate\240\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_width']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_width']._serialized_options = b'\200\246\035\003\212\246\035\036GameRecording\\ExportLimitWidth\240\246\035\200\036'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_height']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_height']._serialized_options = b'\200\246\035\003\212\246\035\037GameRecording\\ExportLimitHeight\240\246\035\360\020'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_frame_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_limit_frame_rate']._serialized_options = b'\200\246\035\003\212\246\035\"GameRecording\\ExportLimitFrameRate\240\246\035<'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_directory']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_directory']._serialized_options = b'\200\246\035\005\212\246\035\035GameRecording\\ExportDirectory'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_codec']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_export_codec']._serialized_options = b'\200\246\035\003\212\246\035\031GameRecording\\ExportCodec'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_video_maxheight']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_video_maxheight']._serialized_options = b'\200\246\035\003\212\246\035\034GameRecording\\VideoMaxHeight\240\246\035\000\330\246\035\000\340\246\035\360\020'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_force_mic_mono']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_force_mic_mono']._serialized_options = b'\200\246\035\003\212\246\035\032GameRecording\\ForceMicMono\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_automatic_gain_control']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamerecording_automatic_gain_control']._serialized_options = b'\200\246\035\003\212\246\035\"GameRecording\\AutomaticGainControl\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['show_timestamps_in_console']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_timestamps_in_console']._serialized_options = b'\200\246\035\003\212\246\035!Developer\\ShowTimestampsInConsole'
  _CMSGCLIENTSETTINGS.fields_by_name['force_oobe']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['force_oobe']._serialized_options = b'\200\246\035\004\212\246\0350HKEY_CURRENT_USER\\Software\\Valve\\Steam\\ForceOOBE'
  _CMSGCLIENTSETTINGS.fields_by_name['override_browser_composer_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['override_browser_composer_mode']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['cef_remote_debugging_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['cef_remote_debugging_enabled']._serialized_options = b'\200\246\035\005'
  _CMSGCLIENTSETTINGS.fields_by_name['force_deck_perf_tab']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['force_deck_perf_tab']._serialized_options = b'\200\246\035\001\212\246\035\032Developer/ForceDeckPerfTab'
  _CMSGCLIENTSETTINGS.fields_by_name['force_fake_mandatory_update']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['force_fake_mandatory_update']._serialized_options = b'\200\246\035\001\212\246\035\035Developer/FakeMandatoryUpdate'
  _CMSGCLIENTSETTINGS.fields_by_name['hdr_compat_testing']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['hdr_compat_testing']._serialized_options = b'\200\246\035\001\212\246\035\032Developer/HDRCompatTesting'
  _CMSGCLIENTSETTINGS.fields_by_name['developer_mode_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['developer_mode_enabled']._serialized_options = b'\200\246\035\001\212\246\035\030Developer/DevModeEnabled'
  _CMSGCLIENTSETTINGS.fields_by_name['show_advanced_update_channels']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['show_advanced_update_channels']._serialized_options = b'\200\246\035\001\212\246\035$Developer/ShowAdvancedUpdateChannels'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_hdr_visualization']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_hdr_visualization']._serialized_options = b'\200\246\035\003\212\246\035\033Gamescope/HDRVisualization2'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_app_target_framerate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_app_target_framerate']._serialized_options = b'\200\246\035\003\212\246\035\034Gamescope/AppTargetFrameRate\240\246\035\000\320\246\035\002'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_enable_app_target_framerate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_enable_app_target_framerate']._serialized_options = b'\200\246\035\004\212\246\035KHKEY_CURRENT_USER\\Software\\Valve\\Steam\\GamescopeEnableAppTargetRefreshRate2\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_disable_framelimit']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_disable_framelimit']._serialized_options = b'\200\246\035\003\212\246\035\033Gamescope/DisableFrameLimit\230\246\035\000\320\246\035\002'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_display_refresh_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_display_refresh_rate']._serialized_options = b'\200\246\035\003\212\246\035\025Gamescope/RefreshRate\240\246\035\000\320\246\035\002'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_use_game_refresh_rate_in_steam']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_use_game_refresh_rate_in_steam']._serialized_options = b'\200\246\035\003\212\246\035#Developer/DynamicRefreshRateInSteam\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_disable_mura_correction']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_disable_mura_correction']._serialized_options = b'\200\246\035\003\212\246\035 Gamescope/MuraCorrectionDisabled\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_include_steamui_in_screenshots']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_include_steamui_in_screenshots']._serialized_options = b'\200\246\035\003\212\246\035%Gamescope/IncludeSteamUIInScreenshots\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_allow_tearing']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_allow_tearing']._serialized_options = b'\200\246\035\003\212\246\035\026Gamescope/AllowTearing\230\246\035\000\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_composite_debug']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_composite_debug']._serialized_options = b'\200\246\035\003\212\246\035\030Gamescope/CompositeDebug\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_force_composite']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_force_composite']._serialized_options = b'\200\246\035\003\212\246\035\030Gamescope/ForceComposite\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_game_resolution_global']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_game_resolution_global']._serialized_options = b'\200\246\035\003\212\246\035\036Gamescope/GameResolutionGlobal\272\246\035\007Default'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_guide_hotkey']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_guide_hotkey']._serialized_options = b'\200\246\035\003\212\246\035\035Gamescope/GuideKeyboardHotkey\272\246\035\rShift\tKEY_TAB'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_qam_hotkey']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_qam_hotkey']._serialized_options = b'\200\246\035\003\212\246\035\033Gamescope/QAMKeyboardHotkey\272\246\035\022CTRL\tShift\tKEY_TAB'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_hdr_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_hdr_enabled']._serialized_options = b'\200\246\035\001\212\246\035\024Gamescope/HDREnabled\230\246\035\001\320\246\035\003'
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_native_external_res_in_steam']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['gamescope_native_external_res_in_steam']._serialized_options = b'\200\246\035\001\212\246\035-Gamescope/EnableSteamNativeExternalResolution'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_status_led_brightness']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_status_led_brightness']._serialized_options = b'\200\246\035\003\212\246\035\033SteamOS/StatusLEDBrightness\240\246\035d'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_tdp_limit_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_tdp_limit_enabled']._serialized_options = b'\200\246\035\001\212\246\035\027SteamOS/TDPLimitEnabled\230\246\035\000\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_tdp_limit']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_tdp_limit']._serialized_options = b'\200\246\035\001\212\246\035\020SteamOS/TDPLimit\240\246\035\000\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_cec_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_cec_enabled']._serialized_options = b'\200\246\035\001\212\246\035\022SteamOS/CECEnabled\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_cec_wake_on_resume']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_cec_wake_on_resume']._serialized_options = b'\200\246\035\001\212\246\035\024SteamOS/WakeOnResume\230\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_wifi_debug']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_wifi_debug']._serialized_options = b'\200\246\035\001\212\246\035\021SteamOS/WifiDebug\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_wifi_force_wpa_supplicant']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_wifi_force_wpa_supplicant']._serialized_options = b'\200\246\035\001\212\246\035\036SteamOS/WifiForceWPASupplicant\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_magnifier_scale']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_magnifier_scale']._serialized_options = b'\200\246\035\003\212\246\035\026SteamOS/MagnifierScale\240\246\035\226\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_manual_gpu_clock_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_manual_gpu_clock_enabled']._serialized_options = b'\200\246\035\001\212\246\035\035SteamOS/ManualGPUClockEnabled\230\246\035\000\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_manual_gpu_clock_hz']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_manual_gpu_clock_hz']._serialized_options = b'\200\246\035\001\212\246\035\030SteamOS/ManualGPUClockHz\240\246\035\350\007\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_platform_performance_profile']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_platform_performance_profile']._serialized_options = b'\200\246\035\001\212\246\035\032SteamOS/PerformanceProfile\320\246\035\001'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit_enabled']._serialized_options = b'\200\246\035\001\212\246\035\032SteamOS/ChargeLimitEnabled\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit']._serialized_options = b'\200\246\035\001\212\246\035\023SteamOS/ChargeLimit\240\246\035P'
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit_devmode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['steamos_charge_limit_devmode']._serialized_options = b'\200\246\035\001\212\246\035\032SteamOS/ChargeLimitDevMode\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_bool']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_bool']._serialized_options = b'\200\246\035\001\212\246\035\033SettingValidation/DummyBool'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_enum']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_enum']._serialized_options = b'\200\246\035\001\212\246\035\033SettingValidation/DummyEnum'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_int32']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_int32']._serialized_options = b'\200\246\035\001\212\246\035\034SettingValidation/DummyInt32'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_uint32']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_uint32']._serialized_options = b'\200\246\035\001\212\246\035\035SettingValidation/DummyUInt32'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_uint64']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_uint64']._serialized_options = b'\200\246\035\001\212\246\035\035SettingValidation/DummyUInt64'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_float']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_float']._serialized_options = b'\200\246\035\001\212\246\035\034SettingValidation/DummyFloat'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_string']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_string']._serialized_options = b'\200\246\035\001\212\246\035\035SettingValidation/DummyString'
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_hotkey']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['setting_validation_hotkey']._serialized_options = b'\200\246\035\001\212\246\035\035SettingValidation/DummyHotkey'
  _CMSGCLIENTSETTINGS.fields_by_name['system_bluetooth_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['system_bluetooth_enabled']._serialized_options = b'\200\246\035\001\212\246\035\030System/Bluetooth/Enabled\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['hardware_updater_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['hardware_updater_enabled']._serialized_options = b'\200\246\035\001\212\246\035\036System/HardwareUpdater/Enabled\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['vr_show_perf_graph_in_hmd']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['vr_show_perf_graph_in_hmd']._serialized_options = b'\200\246\035\003\212\246\035\025VR/ShowPerfGraphInHMD\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_debug_visualizer']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_debug_visualizer']._serialized_options = b'\200\246\035\003\212\246\035\035Accessibility/DebugVisualizer\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_enabled']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_enabled']._serialized_options = b'\200\246\035\001\212\246\035!Accessibility/ScreenReaderEnabled\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_rate']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_rate']._serialized_options = b'\200\246\035\003\212\246\035\037Accessibility/ScreenReaderPitch\265\246\035\000\000\000?'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_pitch']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_pitch']._serialized_options = b'\200\246\035\003\212\246\035\036Accessibility/ScreenReaderRate\265\246\035\000\000\000?'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_volume']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_screen_reader_volume']._serialized_options = b'\200\246\035\003\212\246\035 Accessibility/ScreenReaderVolume\265\246\035\000\000\200?'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_high_contrast_mode']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_high_contrast_mode']._serialized_options = b'\200\246\035\003\212\246\035\036Accessibility/HighContrastMode\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_reduce_motion']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_reduce_motion']._serialized_options = b'\200\246\035\003\212\246\035\032Accessibility/ReduceMotion\230\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_minimum_font_size']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_minimum_font_size']._serialized_options = b'\200\246\035\003\212\246\035\035Accessibility/MinimumFontSize\240\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_color_filter_name']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_color_filter_name']._serialized_options = b'\200\246\035\001\212\246\035\035Accessibility/ColorFilterName\272\246\035\000'
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_desktop_ui_scale']._options = None
  _CMSGCLIENTSETTINGS.fields_by_name['accessibility_desktop_ui_scale']._serialized_options = b'\200\246\035\001\212\246\035\034Accessibility/DesktopUIScale\265\246\035\000\000\200?'
  _ECLIENTSETTINGSTORE._serialized_start=16245
  _ECLIENTSETTINGSTORE._serialized_end=16522
  _EOVERLAYTOGGLEBARLOCATION._serialized_start=16525
  _EOVERLAYTOGGLEBARLOCATION._serialized_end=16706
  _ESETTINGPROFILEMODE._serialized_start=16709
  _ESETTINGPROFILEMODE._serialized_end=16880
  _EGRMODE._serialized_start=16882
  _EGRMODE._serialized_end=16956
  _EGRAUDIO._serialized_start=16958
  _EGRAUDIO._serialized_end=17035
  _EGREXPORTLIMITTYPE._serialized_start=17037
  _EGREXPORTLIMITTYPE._serialized_end=17160
  _CMSGHOTKEY._serialized_start=85
  _CMSGHOTKEY._serialized_end=209
  _CMSGSETTINGVARIANT._serialized_start=212
  _CMSGSETTINGVARIANT._serialized_end=418
  _CMSGCLIENTSETTINGS._serialized_start=421
  _CMSGCLIENTSETTINGS._serialized_end=16242
# @@protoc_insertion_point(module_scope)
